WBConfig

Trait WBConfig 

pub trait WBConfig: SWCurveConfig + Sized {
    type IsogenousCurve: SWUConfig<BaseField = <Self as CurveConfig>::BaseField>;

    const ISOGENY_MAP: IsogenyMap<'static, Self::IsogenousCurve, Self>;
}
Trait defining the necessary parameters for the WB hash-to-curve method.

This method is used for curves in Weierstrass form defined by:

y^2 = x^3 + a*x + b where b != 0, but a can be zero, as seen in curves like BLS-381.

For more information, refer to [WB2019].

Required Associated Constants

const ISOGENY_MAP: IsogenyMap<'static, Self::IsogenousCurve, Self>

Required Associated Types

type IsogenousCurve: SWUConfig<BaseField = <Self as CurveConfig>::BaseField>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors